Reference/API
=============

Capabilities
************

.. automodapi:: astropy.modeling
.. automodapi:: astropy.modeling.bounding_box
.. automodapi:: astropy.modeling.mappings
.. automodapi:: astropy.modeling.fitting
    :inherited-members: True
.. automodapi:: astropy.modeling.optimizers
.. automodapi:: astropy.modeling.statistic
.. automodapi:: astropy.modeling.separable

Pre-Defined Models
******************

.. automodapi:: astropy.modeling.functional_models
.. automodapi:: astropy.modeling.physical_models
.. automodapi:: astropy.modeling.powerlaws
.. automodapi:: astropy.modeling.polynomial
.. automodapi:: astropy.modeling.projections
.. automodapi:: astropy.modeling.rotations
.. automodapi:: astropy.modeling.spline
.. automodapi:: astropy.modeling.tabular
